==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/lv.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'lv', {
	button: {
		title: 'Pogas īpašības',
		text: 'Teksts (vērtība)',
		type: 'Tips',
		typeBtn: 'Poga',
		typeSbm: 'Nosūtīt',
		typeRst: 'Atcelt'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Atzīmēšanas kastītes īpašības',
		radioTitle: 'Izvēles poga īpašības',
		value: 'Vērtība',
		selected: 'Iezīmēts'
	},
	form: {
		title: 'Formas īpašības',
		menu: 'Formas īpašības',
		action: 'Darbība',
		method: 'Metode',
		encoding: 'Kodējums'
	},
	hidden: {
		title: 'Paslēptās teksta rindas īpašības',
		name: 'Nosaukums',
		value: 'Vērtība'
	},
	select: {
		title: 'Iezīmēšanas lauka īpašības',
		selectInfo: 'Informācija',
		opAvail: 'Pieejamās iespējas',
		value: 'Vērtība',
		size: 'Izmērs',
		lines: 'rindas',
		chkMulti: 'Atļaut vairākus iezīmējumus',
		opText: 'Teksts',
		opValue: 'Vērtība',
		btnAdd: 'Pievienot',
		btnModify: 'Veikt izmaiņas',
		btnUp: 'Augšup',
		btnDown: 'Lejup',
		btnSetValue: 'Noteikt kā iezīmēto vērtību',
		btnDelete: 'Dzēst'
	},
	textarea: {
		title: 'Teksta laukuma īpašības',
		cols: 'Kolonnas',
		rows: 'Rindas'
	},
	textfield: {
		title: 'Teksta rindas  īpašības',
		name: 'Nosaukums',
		value: 'Vērtība',
		charWidth: 'Simbolu platums',
		maxChars: 'Simbolu maksimālais daudzums',
		type: 'Tips',
		typeText: 'Teksts',
		typePass: 'Parole',
		typeEmail: 'Epasts',
		typeSearch: 'Meklēt',
		typeTel: 'Tālruņa numurs',
		typeUrl: 'Adrese'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/lv.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'lv', {
	button: {
		title: 'Pogas īpašības',
		text: 'Teksts (vērtība)',
		type: 'Tips',
		typeBtn: 'Poga',
		typeSbm: 'Nosūtīt',
		typeRst: 'Atcelt'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Atzīmēšanas kastītes īpašības',
		radioTitle: 'Izvēles poga īpašības',
		value: 'Vērtība',
		selected: 'Iezīmēts',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Formas īpašības',
		menu: 'Formas īpašības',
		action: 'Darbība',
		method: 'Metode',
		encoding: 'Kodējums'
	},
	hidden: {
		title: 'Paslēptās teksta rindas īpašības',
		name: 'Nosaukums',
		value: 'Vērtība'
	},
	select: {
		title: 'Iezīmēšanas lauka īpašības',
		selectInfo: 'Informācija',
		opAvail: 'Pieejamās iespējas',
		value: 'Vērtība',
		size: 'Izmērs',
		lines: 'rindas',
		chkMulti: 'Atļaut vairākus iezīmējumus',
		required: 'Required', // MISSING
		opText: 'Teksts',
		opValue: 'Vērtība',
		btnAdd: 'Pievienot',
		btnModify: 'Veikt izmaiņas',
		btnUp: 'Augšup',
		btnDown: 'Lejup',
		btnSetValue: 'Noteikt kā iezīmēto vērtību',
		btnDelete: 'Dzēst'
	},
	textarea: {
		title: 'Teksta laukuma īpašības',
		cols: 'Kolonnas',
		rows: 'Rindas'
	},
	textfield: {
		title: 'Teksta rindas  īpašības',
		name: 'Nosaukums',
		value: 'Vērtība',
		charWidth: 'Simbolu platums',
		maxChars: 'Simbolu maksimālais daudzums',
		required: 'Required', // MISSING
		type: 'Tips',
		typeText: 'Teksts',
		typePass: 'Parole',
		typeEmail: 'Epasts',
		typeSearch: 'Meklēt',
		typeTel: 'Tālruņa numurs',
		typeUrl: 'Adrese'
	}
} );
